@@ -1,19 +1,8 @@
-/* *************************************************************************
- *  Copyright 2015 Jakob Gruber <jakob.gruber@gmail.com>                   *
- *                                                                         *
- *  This program is free software: you can redistribute it and/or modify   *
- *  it under the terms of the GNU General Public License as published by   *
- *  the Free Software Foundation, either version 2 of the License, or      *
- *  (at your option) any later version.                                    *
- *                                                                         *
- *  This program is distributed in the hope that it will be useful,        *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- *  GNU General Public License for more details.                           *
- *                                                                         *
- *  You should have received a copy of the GNU General Public License      *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
- ************************************************************************* */
+/*
+    SPDX-FileCopyrightText: 2015 Jakob Gruber <jakob.gruber@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "streaks.h"
 
@@ -127,7 +116,7 @@ Streaks::processStreak(const QVector<StreakPrivate> &map,
     for (int i = 0; i < streaks_reversed.size(); i++) {
         streaks_reversed[i].begin = l.size() - streaks_reversed[i].begin;
         streaks_reversed[i].end   = l.size() - streaks_reversed[i].end;
-        qSwap(streaks_reversed[i].begin, streaks_reversed[i].end);
+        std::swap(streaks_reversed[i].begin, streaks_reversed[i].end);
     }
 
     /* Preliminary checks
